<?php
/**
Plugin Name: Simple Portfolio
Plugin URI: http://projects.inlet.nl/simple-portfolio-wordpress3/
Description: Manage your portfolio projects easily and use them everywhere you like. This plugin is very simple to use, it doesn't bother you with a complex user interface. Add project specific information, for example what your role was and the team you've worked in, etc. Add any media you like: YouTube, code snippets or any media from your wordpress built-in Media Library. Wonder how it works? Watch the <a href="http://www.inlet.nl">screencast</a>.
Version: 1.1
Author: Patrick Brouwer (Inlet)
Author URI: http://www.inlet.nl

    Copyright 2010 Patrick Brouwer  (email : patrick@inlet.nl)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

include('extends/init.php');
include('extends/settings-panel.php');
include('extends/dashboard.php');
include('extends/admin-head.php');
include('extends/admin-menu.php');
include('extends/save-post.php');
include('extends/rewrite.php');
include('extends/wp-head.php');
include('extends/columns.php');

/**
* Retrieves all portfolio media items for provided Post or Page
* @param int (optional) ID of target Post or Page, otherwise pulls from global $post
* @return array $post_portfolio_media
*/
function simple_portfolio_media(  $post_id = null, $type = null  ) {
	global $post;
	if ($post_id == null) $post_id = $post->ID;
	
	$media = get_post_meta( $post_id, 'portfolio_media', false );
	$media = (is_array($media) && count($media) > 0) ? unserialize(base64_decode($media[0])) : array();
	
	if ($type != null):
		$new_media = array();
		foreach ($media as $value):
			if ($value['type'] == $type) 
				$new_media[] = $value;
		endforeach;
		$media = $new_media;
	endif;
	
	return $media;
}

/**
* Retrieves all portfolio general information for provided Post or Page
* @param int (optional) ID of target Post or Page, otherwise pulls from global $post
* @return array $post_portfolio_info
*/
function simple_portfolio_info( $post_id = null ) {
	global $post;
	if ($post_id == null) $post_id = $post->ID;
	
	$custom = get_post_custom( $post_id );
	$post_portfolio_info = array();
	
	foreach (get_option_preformatted() as $key=>$value):
		$post_portfolio_info['portfolio_' . $key] = isset($custom['portfolio_' . $key]) ? $custom['portfolio_' . $key][0] : '';
	endforeach;
	
	return $post_portfolio_info;
}

/**
 * Returns all portfolio projects.
 * This way you can loop through all projects anywhere you like.
 * @return array
 */
function simple_portfolio_all_projects() {
	return query_posts('post_type=portfolio'); 
}

/**
 * Is xml enabled?
 * @return Boolean
 */
function simple_portfolio_xml_enabled() {
	return get_option('use-xml') == '1' ? true : false;
}

?>